#
# spec file for package python-calmjs
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-calmjs
Version:        3.4.2
Release:        bp154.1.16
Summary:        A Python framework for working with the Node.js ecosystem
License:        GPL-2.0-or-later
URL:            https://github.com/calmjs/calmjs/
Source:         https://github.com/calmjs/calmjs/archive/%{version}.tar.gz
BuildRequires:  %{python_module calmjs.parse >= 1.0.0}
BuildRequires:  %{python_module calmjs.types}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-calmjs.parse >= 1.0.0
Requires:       python-calmjs.types
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  nodejs-common
# /SECTION
%python_subpackages

%description
A Python framework for building toolchains and utilities for working
with the Node.js ecosystem from within a Python environment.

%prep
%setup -q -n calmjs-%{version}
# needs network and npm
rm src/calmjs/tests/test_npm.py
# we don't have yarn binary
rm src/calmjs/tests/test_yarn.py

%build
export LANG=en_US.UTF-8
%python_build

%install
export LANG=en_US.UTF-8
%python_install
%python_clone -a %{buildroot}%{_bindir}/calmjs
# %%python_expand rm -r %%{buildroot}%%{$python_sitelib}/calmjs/testing
# %%python_expand rm -r %%{buildroot}%%{$python_sitelib}/calmjs/tests
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
# gh#calmjs/calmjs#61
# %%python_expand rm -v %%{buildroot}%%{$python_sitelib}/calmjs/tests/test_argparse.py
%pyunittest -v calmjs.tests.make_suite

%post
%python_install_alternative calmjs

%postun
%python_uninstall_alternative calmjs

%files %{python_files}
%license LICENSE
%doc CHANGES.rst
%python_alternative %{_bindir}/calmjs
%{python_sitelib}/*

%changelog
* Tue Nov 16 2021 Matej Cepl <mcepl@suse.com>
- Remove creation of the unnecessary __init__py, which breaks the test
  suite (gh#calmjs/calmjs#61).
* Thu Nov 11 2021 Matej Cepl <mcepl@suse.com>
- Update to 3.4.2:
  - This is a maintenance release for Python 3.10; no substantial
    changes were been made.
  - Provided a check for disabling integration tests using the
    CALMJS_SKIP_INTEGRATION environment variable, when set to a non-
    empty string, the integration tests found in test_dist will be
    skipped. [ #60 ]
- Fix running of tests (gh#calmjs/calmjs#61).
* Fri Jan 22 2021 Markéta Machová <mmachova@suse.com>
- Launch the tests again.
* Tue Jan 14 2020 pgajdos@suse.com
- fix build in SLE-15: set en_US.UTF-8 encoding
- %%check the package
* Mon Jan  6 2020 Tomáš Chvátal <tchvatal@suse.com>
- Disable tests as getting them to work is too much of a pain
* Mon Jan  6 2020 Tomáš Chvátal <tchvatal@suse.com>
- Initial commit, needed by django-compressor
